# PasswordManagerPy

This is a simple password manager written in python.

It takes a username and website which are optional and a password length.

A random password will be created and appended to an encrypted text file.

This file can be decrypted and viewed from the GUI.